Struct SimpleMem2MemTransfer
Source pub struct SimpleMem2MemTransfer<'a, 'd, Dm>()
where
Dm: DriverMode;
Available on crate feature unstable only.
Represents an ongoing (or potentially finished) DMA Memory-to-Memory
transfer.
Wait for the transfer to finish.
Executes the destructor for this type.
Read more
🔬This is a nightly-only experimental API. (pin_ergonomics)
Execute the destructor for this type, but different to
Drop::drop, it requires
self
to be pinned.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.